@@ -1,4 +1,4 @@
-/* Copyright (C) 2000-2002 Damir Zucic */
+/* Copyright (C) 2000-2003 Damir Zucic */
 
 /*=============================================================================
 
@@ -11,7 +11,7 @@ Purpose:
 
 Input:
 	(1) Pointer to MolComplexS structure, with macromolecular data.
-	(2) Hydrophobicity scale index (zero for default scale).
+	(2) Hydrophobicity scale index.
 
 Output:
 	(1) Hydrophobicity information assigned to each atom.
@@ -26,6 +26,8 @@ Notes:
 	(1) The average  hydrophobicity  is assigned to all atoms which
 	    belong to unknown (unidentifyed) residues.
 
+	(2) Check init_runtime.c for default hydrophobicity scale!
+
 ========includes:============================================================*/
 
 #include <stdio.h>
