@@ -128,7 +128,6 @@ double		cos_theta1, cos_theta2, cos_theta12;
 /* Geometric parameters: */
 min_dist = configSP->hydro_bond_length_min;
 max_dist = configSP->hydro_bond_length_max;
-
 min_distance_squared = configSP->hydro_min_squared;
 max_distance_squared = configSP->hydro_max_squared;
 
@@ -475,6 +474,9 @@ for (mol_complexI = 0; mol_complexI < mol_complexesN; mol_complexI++)
 	    if (r12 <= 2.0) continue;      /* This covers zero value! */
 	    reciprocal_r12 = 1.0 / r12;
 
+	    /*@@*/ /* TEMPORARY CRUDE CHECK. REPLACE THIS LATER! */
+	    if (r12 > 3.7) continue;
+
 	    /* Calculate  and  check  cos_theta1,  the cosine  of the */
 	    /* angle between  the first dipole and the vector between */ 
 	    /* two dipoles.  This cosine belongs to the hydrogen bond */
@@ -519,6 +521,18 @@ for (mol_complexI = 0; mol_complexI < mol_complexesN; mol_complexI++)
 
 	    /* Update the counter: */
 	    hydrogen_bondsN++;
+
+	    /*@@*/ /* TEMPORARY CHANGES: */
+	    if (r12 > max_dist) continue; /*@@*/
+
+#ifdef ALLDONE /*@@*/
+	    /*@@*/ /* CREATE DUMMY ATOMS: */
+	    printf ("ATOM%7ld  J   JEL%6ld    %8.3f%8.3f%8.3f  1.00 10.00\n",
+		    hydrogen_bondsN + 100, hydrogen_bondsN + 100,
+		    10 * cos_theta1,
+		    10 * cos_theta2,
+		    10 * r12);
+#endif /*@@*/
 	    }
 	}
 
