@@ -86,7 +86,7 @@ char		*remainderP;
 char		tokenA[SHORTSTRINGSIZE];
 FILE		*fileP;
 int		chainI = 0;
-char		chainIDA[30] = "ABCDEFGHIJKLMNOPQRSTUVWXYZ";
+static char	chainIDA[30] = "ABCDEFGHIJKLMNOPQRSTUVWXYZ";
 char		chainID;
 int		complexID;
 int		mol_complexI;
