@@ -1,4 +1,4 @@
-/* Copyright (C) 2000-2003 Damir Zucic */
+/* Copyright (C) 2000-2004 Damir Zucic */
 
 /*=============================================================================
 
@@ -30,7 +30,7 @@ Notes:
 	(2) Threshold hydrophobicy  is used  to distinguish hydrophobic
 	    and hydrophilic residues.  Residue which has hydrophobicity
 	    value above the threshold should be treated as hydrophobic.
-	    For Kyte-Doolittle scale and  White scale,  positive values
+	    For Kyte-Doolittle scale and White scales,  positive values
 	    are assigned to hydrophobic residues and threshold value is
 	    equal to zero. For normalized Eisenberg scale, threshold is
 	    different from zero. This is caused by normalization.
@@ -38,13 +38,18 @@ Notes:
 	(3) References:
 
 	    ===========================================================
-	    | Scale           |  Reference                            |
+	    | Scale(s)        |  Reference                            |
 	    ===========================================================
 	    | S. White group  |  Biochemistry   35 (1996), p. 5109.   |
 	    | Kyte-Doolitle   |  J. Mol. Biol. 157 (1982), p.  105.   |
 	    | Eisenberg       |  J. Mol. Biol. 179 (1984), p.  125.   |
 	    ===========================================================
 
+	(4) Check init_runtime.c for default hydrophobicity scale!
+
+	(5) Twenty standard residues are used  to calculate the average
+	    hydrophobicity value: ASX, GLX and UNK are not used.
+
 ========includes:============================================================*/
 
 #include <stdio.h>
@@ -65,29 +70,51 @@ static char	amino_acidAA[23][4] =
 
 static double	hyphob_scaleAA[SCALESN][23] =
 
-		 /* White & Wimley octanol scale */
-		{{-0.50,-1.81,-0.85,-3.64, 0.02,-0.77,-3.63,-1.15,-2.33, 1.12,
+		/* 0: White & Wimley octanol scale, OCT (was WHI before): */
+		{{-0.50,-1.81,-0.85,-3.64, 0.02,-0.77,-3.63,-1.15,-0.11, 1.12,
 		   1.25,-2.80, 0.67, 1.71,-0.14,-0.46,-0.25, 2.09, 0.71, 0.46,
-		  -2.25,-2.20,-0.52},
+		  -2.25,-2.20,-0.40}, /* Note: HIS is neutral! */
 
-		 /* Kyte & Doolittle hydropathy scale */
+		/* 1: Kyte & Doolittle hydropathy scale, KD: */
 		 { 1.80,-4.50,-3.50,-3.50, 2.50,-3.50,-3.50,-0.40,-3.20, 4.50,
 		   3.80,-3.90, 1.90, 2.80,-1.60,-0.80,-0.70,-0.90,-1.30, 4.20,
 		  -3.50,-3.50,-0.49},
 
-		 /* Eisenberg normalized consensus sc. */
+		/* 2: Eisenberg normalized consensus scale, EIS: */
 		 { 0.62,-2.53,-0.78,-0.90, 0.29,-0.85,-0.74, 0.48,-0.40, 1.38,
 		   1.06,-1.50, 0.64, 1.19, 0.12,-0.18,-0.05, 0.81, 0.26, 1.08,
-		  -0.84,-0.80, 0.00}};
+		  -0.84,-0.80, 0.00},
 
-static double	min_hyphobA[SCALESN]       = {-3.64, -4.50, -2.53};
-static double	max_hyphobA[SCALESN]       = { 2.09,  4.50,  1.38};
-static double	average_hyphobA[SCALESN]   = {-0.52, -0.49,  0.00};
-static double	threshold_hyphobA[SCALESN] = { 0.00,  0.00, -0.16};
+		/* 3: White & Wimley interface scale, HIS neutral, INT: */
+		 {-0.17,-0.81,-0.42,-1.23, 0.24,-0.58,-2.02,-0.01,-0.17, 0.31,
+		   0.56,-0.99, 0.23, 1.13,-0.45,-0.13,-0.14, 1.85, 0.94,-0.07,
+		  -0.83,-1.30,-0.10}, /* Note: HIS is neutral! */
+
+		/* 4: Interface scale, HIS, ASP and GLU neutral, IN2: */
+		 {-0.17,-0.81,-0.42,-0.07,-0.24,-0.58, 0.01,-0.01,-0.17, 0.31,
+		   0.56,-0.99, 0.23, 1.13,-0.45,-0.13,-0.14, 1.85, 0.94,-0.07,
+		  -0.25,-0.30, 0.04}, /* Note: HIS, ASP and GLU are neutral! */
+
+		/* 5: Differential scale, OCT-INT, HIS neutral, DIF: */
+		 {-0.33,-1.00,-0.43,-2.41,-0.22,-0.19,-1.61,-1.14, 0.06, 0.81,
+		   0.69,-1.81, 0.44, 0.58, 0.31,-0.33,-0.11, 0.24,-0.23, 0.53,
+		  -1.38,-0.90,-0.31}};
+
+		/*-----------------------------------*/
+		/* OCT   KD    EIS   INT   IN2   DIF */
+		/*-----------------------------------*/
+static double	min_hyphobA[SCALESN]       =
+		{-3.64,-4.50,-2.53,-2.02,-0.99,-2.41};
+static double	max_hyphobA[SCALESN]       =
+		{ 2.09, 4.50, 1.38, 1.85, 1.85, 0.81};
+static double	average_hyphobA[SCALESN]   =
+		{-0.40,-0.49, 0.00,-0.10, 0.04,-0.31};
+static double	threshold_hyphobA[SCALESN] =
+		{ 0.00, 0.00,-0.16, 0.00, 0.00, 0.00};
 int		i;
 
 /* Check scale index: */
-if (scaleI > SCALESN) return 0.0;
+if (scaleI >= SCALESN) return 0.0;
 
 /* If minimal hydrophobicity is requested: */
 if (requestI == 1) return min_hyphobA[scaleI];
