@@ -1,4 +1,4 @@
-/* Copyright (C) 2000-2004 Damir Zucic */
+/* Copyright (C) 2000-2006 Damir Zucic */
 
 /*=============================================================================
 
@@ -26,17 +26,17 @@ void PrintVersion_ (void)
 {
 fprintf (stdout, "\n");
 fprintf (stdout, "==================================\n");
-fprintf (stdout, "garlic version 1.4\n");
-fprintf (stdout, "Last revision: 2004/October/29\n");
+fprintf (stdout, "garlic version 1.5\n");
+fprintf (stdout, "Release date: 2006/January/12\n");
 fprintf (stdout, "==================================\n");
 fprintf (stdout, "\n");
 fprintf (stdout, "Compliant with PDB version 2.1");
 fprintf (stdout, " (draft, October 25, 1996).\n");
 fprintf (stdout,
-	 "Copyright (C) 2000-2004 Damir Zucic (zucic@garlic.mefos.hr).\n");
+	 "Copyright (C) 2000-2006 Damir Zucic (zucic@garlic.mefos.hr).\n");
 fprintf (stdout, "Source code, documentation and binaries:\n");
 fprintf (stdout, "\n=====================================\n");
-fprintf (stdout, "  http://garlic.mefos.hr/garlic-1.4\n");
+fprintf (stdout, "  http://garlic.mefos.hr/garlic-1.5\n");
 fprintf (stdout, "=====================================\n\n");
 }
 
