@@ -1,4 +1,4 @@
-/* Copyright (C) 2000-2004 Damir Zucic */
+/* Copyright (C) 2000-2006 Damir Zucic */
 
 
 /* Structures used in garlic program. */
@@ -412,6 +412,13 @@ typedef struct		/* GUIS */
 	int		main_hidden_pixmapF;
 	Pixmap		main_hidden_pixmapID;
 
+	/* The hidden pixmap with small blue arrows. These arrows are used */
+	/* to show the main chain direction,  projected to the  XY  plane. */
+	int		small_arrows_pixmapF;
+	unsigned int	small_arrows_width;
+	unsigned int	small_arrows_height;
+	Pixmap		small_arrows_pixmapID;
+
 	/* Array of graphics contexts: */
 	GC		theGCA[10];
 	int		gca_createdF;
@@ -1210,6 +1217,7 @@ typedef struct		/* RuntimeS */
 	double		*function5P;                /* Hydroph. function F5  */
 
 	int		*auxiliaryIP;               /* Aux. integer storage  */
+	double		*aux_doubleP;               /* Aux. double storage   */
 
 	size_t		reference_residuesN;        /* Reference seq. length */
 	char		*reference_sequenceP;       /* Reference seq. buffer */
